/*\file Mergesolutionfromftog.c
 *\brief: merge solution back from f set into g set
 */

#include "./Mergesolutionfromftog.h"

void mexFunction( int nlhs, mxArray* plhs[], int nrhs, const mxArray* prhs[]){

	/*input datasets: */
	bool        flag_ys0;
	Vector*         uf         = NULL;
	Vector*         ys         = NULL;
	Nodes*      nodes   = NULL;
	Parameters* parameters   = NULL;

	/* output datasets: */
	Vector* ug=NULL;

	/*Boot module: */
	MODULEBOOT();

	/*checks on arguments on the matlab side: */
	if((nlhs!=NLHS) || (nrhs!=4 && nrhs!=5)){
		MergesolutionfromftogUsage();
		_error_(" usage. See above");
	}

	/*Input datasets: */
	FetchMatlabData(&uf,UF);
	FetchMatlabData(&ys,YS);
	FetchMatlabData((DataSet**)&nodes,NODES);
	FetchMatlabData(&parameters,PARAMETERS);

	/*!Reduce vector: */
	if (nrhs==4){
		Mergesolutionfromftogx(&ug, uf,ys,nodes,parameters);
	}
	else{
		FetchMatlabData(&flag_ys0,YSFLAG);
		Mergesolutionfromftogx(&ug, uf,ys,nodes,parameters,flag_ys0);
	}

	/*write output datasets: */
	WriteMatlabData(UG,ug);

	/*Free ressources: */
	xdelete(&uf);
	xdelete(&ug);
	xdelete(&ys);
	delete nodes;
	delete parameters;

	/*end module: */
	MODULEEND();
}

void MergesolutionfromftogUsage(void)
{
	_printf_(true,"\n");
	_printf_(true,"   usage: [ug] = %s(uf,ys,nodes,parameters,[flag_ys0]);\n",__FUNCT__);
	_printf_(true,"\n");
}
